/*******************************************************************************
* FILE NAME: OI_routines.c
*
* DESCRIPTION:
*    Update the OI display LEDs and the dashboard status information
*
*******************************************************************************/

#include "ifi_aliases.h"
#include "ifi_default.h"
#include "ifi_utilities.h"

#include "user_routines.h"
#include "tracking.h"

#define OFF 0
#define ON   1
#define NULLJOYSTICK 10  //This value should be greater than the Victor neutral deadspot

void OI_Display()
{
 /*---------- OI LEDs------------------------------------------------
  *------------------------------------------------------------------
  *   This section drives the "ROBOT FEEDBACK" lights on the Operator Interface.
  *   The lights are green for joystick forward and red for joystick reverse.
  *   Both red and green are on when the joystick is centered.  Use the
  *   trim tabs on the joystick to adjust the center.
  */	
  
  if (user_display_mode == OFF) /* User Mode is Off so the LED indicators are in use */
  { 
    // Driver on Joystick ports 1 & 2, Arm on Joystick port 3, Switch box on port 4
    // PWM1 LEDs - Port 1 y axis
    // PWM2 LEDs - Port 2 y axis
    // Relay1 LEDs - Port 3 y axis
    // Relay2 LEDs - Down looking Sonic sees spider (goggle LEDs)
    // Switch1_LED - Camera tracking
    // Switch2_LED - Set in Auto & Opr as last second timer
    // Switch3_LED - Compressor on/off

    /********* Joystick trim *********/
    /**** Display trim position of Port 1 Drive y Joystick ****/
    if (LEFT_DRIVE > (127-NULLJOYSTICK) )
      Pwm1_green  = ON;
    else
      Pwm1_green  = OFF;

    if (LEFT_DRIVE <  (127+NULLJOYSTICK) )
      Pwm1_red  = ON;
    else
      Pwm1_red  = OFF;

    /**** Display trim position of Port 2 Drive y Joystick ****/
    if (RIGHT_DRIVE > (127-NULLJOYSTICK) )
        Pwm2_green  = ON;
    else
        Pwm2_green  = OFF;

    if (RIGHT_DRIVE <  (127+NULLJOYSTICK) )
        Pwm2_red  = ON;
    else
        Pwm2_red  = OFF;


    /**** Display trim position of Port 3 Arm Joystick x ****/
    if (TURRET_DRIVE > (127-NULLJOYSTICK) )
      Relay1_green  = ON;
    else
      Relay1_green  = OFF;
    if (TURRET_DRIVE <  (127+NULLJOYSTICK) )
      Relay1_red  = ON;
    else
      Relay1_red  = OFF;

  // ****** Sonic tracking *****
	if (Spider_Sonic_Check() == TRUE)
	{ // An object at the correct distance has been spotted
		Relay2_green  = ON;
		Relay2_red  = ON;
	}
	else
	{
		Relay2_green  = OFF;
		Relay2_red  = OFF;
	}

  /**** Miscellaneous indicators ****/
#if (0)
	if(Get_Tracking_State() == CAMERA_ON_TARGET)
	{
		Switch1_LED = 1;
	}
	else
	{
		Switch1_LED = 0;
	}
#endif

  //Switch2_LED = OFF; Set in Auto & Opr as last second timer
  Switch3_LED = relay8_fwd; // Compressor on or off
    
  } /* (user_display_mode = 0) (User Mode is Off) */
  
  else  /* User Mode is On - displays data in OI 4-digit display */
  {

 /*---------- OI User Mode Display-----------------------------------
  *------------------------------------------------------------------
  */
// Field Position + Autonomous Selected

//    User_Mode_byte = backup_voltage*10; /* so that decimal doesn't get truncated. */
#ifdef MLM
    User_Mode_byte = AUTOMODE;  // Autonomous version selected

    // Field position
    if (rc_dig_in11 == 0) 
    {
      User_Mode_byte += 100; // Right
    }
    else if (rc_dig_in12 == 0)
    {
      User_Mode_byte += 200; // Left
    }
    else if (rc_dig_in13 == 0)
    {
//      User_Mode_byte += 0; // Center
    }
#endif

  }


 /*---------- Dashboard Display --------------------------------------------------
  *------------------------------------------------------------------------------
  */

  User_Byte1  = 0; // Available
  User_Byte2  = 0; // Available
  User_Byte3  = 0; // Available
  User_Byte4  = 0; // Available
  User_Byte5  = 0; // Available
}
