/*******************************************************************************
* FILE NAME: auto_routines.h
*
* DESCRIPTION:
*  This file contains several sample autonomous techniques as a
*  progressive development from prinitive to more sophisticated.
*******************************************************************************/

#ifndef __auto_routines_h_
#define __auto_routines_h_

#ifdef VARIABLE_DECLARE
   char Arm_Status, Drive_Status, Joint_Status;
   int lastDriveCmd, lastArmCmd, lastJointCmd;
   unsigned char DriveCmd, ArmCmd, JointCmd; // Current cmd # in script
   unsigned char cmdNum,lastcmdNum;
   unsigned char start_position = 0;
#else
  extern char Arm_Status, Drive_Status, Joint_Status;
  extern int lastDriveCmd, lastArmCmd, lastJointCmd;
  extern unsigned char DriveCmd, ArmCmd, JointCmd; // Current cmd # in script
  extern unsigned char cmdNum,lastcmdNum;
  extern unsigned char start_position;
#endif

/**** Script Commands ****/
  #define ENDCMD        0   /* Must always be the last command */

  /* Driving commands */
  #define DFWD          1   /* Drive Forward for a time */
  #define DBCK          2   /* Drive Backward for a time */
  #define DSPIN         3   /* Spin in place for a time */
  #define DSONIC	   4	// Drive to a set distance from the rack or an obstacle
  #define DSTOP         7   /* Stop all engines */
  #define DCURVE       8   /* Drive Forward for a time */
  /* Add new drive cmds here */
  #define LASTDRIVECMD         19   // Keep as last Drive command (unused)

  /* Joint commands - requires both Arm and drive queues to complete */
  #define DELAY   	    20  /* Sit still for a time */
  #define SYNC          21  /* Wait for both Arm and drive cmds to complete before proceeding */
 /* Add new joint cmds here */

  /* Arm commands */
  #define FIRSTARMCMD    30    // Keep as first Arm command
  #define AHIGH    31   //
  #define AMED	    32   //
  #define ALOW	    33   //
  #define ALETGO 34   //
  #define AUNFOLD 35   //
  #define ASONIC 36 //
  #define ATURRET 37

  /* Add new Arm cmds here */

  /******** End Script Commands *********/

  /* command array indexes - cmd parameters depend on the cmd */
  #define CMD           0

  #define CMDTIME       1
  #define CMDDIST       1
  #define CMDDISTRIGHT  1
  #define CMDSETTING    1

  #define CMDSPEED      2
  #define CMDPERCENT     2

  #define CMDDIRECTION  3
  #define CMDFASTER     3

  /*************************/

/* Direction, speed */
#define CW               1  // Clockwise
#define CCW              0  // Counter clockwise
#define NONE             0
#define NEUTRAL          127
#define FULLSPEED      127 
#define HALFSPEED       64
#define QTRSPEED        32
#define MINTURNSPEED    70  // Minimum speed in autonomous turn (was 50)
#define MINSPEED        30  // Minimum speed driving straight (25 is absolute min)

#define MAXTIME			65535

/* Command queue status */
#define COMPLETE     0
#define INCOMPLETE   1
#define JOINT        2

#define STARTLEFT   1
#define STARTCENTER 2
#define STARTRIGHT  3

/* This is the autonomous mode switched to.... this is always called in autonomous... */

void Switch_Auto(rom const int *);

/*Driving functions */
void Drive_Forward_Time(int,int);
void Drive_Backward_Time(int,int);
void Drive_Spin_In_Place_Time(int, int, int);
void Drive_Stop(void);
void Drive_Sonic(int,int);
void Drive_Curve(int , int , int );

/* Arm functions */
void Arm_Auto_Unfold(void);
void Arm_Auto_High(void);
void Arm_Auto_Medium(void);
void Arm_Auto_Low(void);
void Arm_Auto_Letgo(void);
void Arm_Turret(int);
void Arm_Search_Pattern(char);

/* Miscellaneous */
void Delay(int);
void Sync_Drive_Arm(int);

#endif
