/*******************************************************************************
* FILE NAME: auto_scripts.c
*
* DESCRIPTION:
*  These are all the autonomous command scripts
*  The auto script is selected via the 10 position auto mode switch on the robot.
*
* USAGE:
*  Modify scripts as required
*  Cut & Paste command templates located at the bottom of this file
*
*  Drive commands must be intermixed with Shooter commands carefully.
*  Two of either type in a row will block further command processing
*  until one of them has cleared the queue.
*
* Avoid running motors at full speed, so PID has room to adjust
*
*******************************************************************************/
#define AUTO_HEIGHT		30  // Maximum number of script commands
#define AUTO_WIDTH		4   // Maximum number of command parameters

//***********************
//   Auto 0  - Do nothing
//   Auto 1  - Cap tube on MEDIUM spider (sonic sensors)
//   Auto 2  - Cap tube on HIGH spider (sonic sensors)
//   Auto 3  - Drive straight raise arm and drop tube (Deadreckon)
//   Auto 4  - Drive out raise arm and wait
//   Auto 5  - 
//   Auto 6  - 
//   Auto 7  - 
//   Auto 8  - 
//   Auto 9  - Testing
//***********************

/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_0[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Do nothing, sit still, don't move, try not to breathe
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_0[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Do nothing, sit still, don't move, try not to breathe
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_0[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Do nothing, sit still, don't move, try not to breathe
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_1[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
   DBCK,     10,   FULLSPEED,     0,  // Drive backward (time,speed)
   SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   ALETGO,     0,         0,        0,  // Release the tube
   AMED,      0,         0,        0,  // Move arm to medium scoring position
   ALOW,     0,         0,        0,  // Move arm to low scoring position
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_1[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // 
   DBCK,     10,   FULLSPEED,     0,  // Drive backward (time,speed)
   SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   ALETGO,     0,         0,        0,  // Release the tube
   AMED,      0,         0,        0,  // Move arm to medium scoring position
   ALOW,     0,         0,        0,  // Move arm to low scoring position
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_1[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
   DBCK,     10,   FULLSPEED,     0,  // Drive backward (time,speed)
   SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   ALETGO,     0,         0,        0,  // Release the tube
   AMED,      0,         0,        0,  // Move arm to medium scoring position
   ALOW,     0,         0,        0,  // Move arm to low scoring position
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_2[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // 
   //AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   DFWD,     30,   FULLSPEED,     0,  // Drive Forward (time,speed)
   //AMED,      0,         0,        0,  // Move arm to medium scoring position
   //SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   //DSONIC, 87,	0,	0,	//Drive to predefined distance from rack
   //SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   //ASONIC, 17,	0,	0,	//Search with arm turret for distance
   //ALETGO,     0,         0,        0,  // Release the tube
   //DELAY,    40,		0,		0,  // Sit still (time)
   //DBCK,     10,   QTRSPEED,     0,  // Drive Backward (time,speed)
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_2[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // 
   //AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   DFWD,     30,   FULLSPEED,     0,  // Drive Forward (time,speed)
  // AMED,      0,         0,        0,  // Move arm to medium scoring position
   //SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   //DSONIC, 87,	0,	0,	//Drive to predefined distance from rack
   //SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   //ASONIC, 17,	0,	0,	//Search with arm turret for distance
   //ALETGO,     0,         0,        0,  // Release the tube
   //DELAY,    40,		0,		0,  // Sit still (time)
   //DBCK,     10,   QTRSPEED,     0,  // Drive Backward (time,speed)
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_2[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // 
   //AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   DFWD,     30,   FULLSPEED,     0,  // Drive Forward (time,speed)
   //AMED,      0,         0,        0,  // Move arm to medium scoring position
   //SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   //DSONIC, 87,	0,	0,	//Drive to predefined distance from rack
   //SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   //ASONIC, 17,	0,	0,	//Search with arm turret for distance
   //ALETGO,     0,         0,        0,  // Release the tube
   //DELAY,    40,		0,		0,  // Sit still (time)
   //DBCK,     10,   QTRSPEED,     0,  // Drive Backward (time,speed)
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_3[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   AMED,      0,         0,        0,  // Move arm to medium scoring position
   ALOW,     0,         0,        0,  // Move arm to low scoring position
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_3[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   AMED,      0,         0,        0,  // Move arm to medium scoring position
   ALOW,     0,         0,        0,  // Move arm to low scoring position
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_3[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   AMED,      0,         0,        0,  // Move arm to medium scoring position
   ALOW,     0,         0,        0,  // Move arm to low scoring position
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_4[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_4[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_4[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_5[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_5[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_5[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
 
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_6[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
  ENDCMD, NONE,  NONE,       NONE    //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_6[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
  ENDCMD, NONE,  NONE,       NONE    //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_6[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
  ENDCMD, NONE,  NONE,       NONE    //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_7[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_7[AUTO_HEIGHT*AUTO_WIDTH] = 
  {// 
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_7[AUTO_HEIGHT*AUTO_WIDTH] = 
  {// 
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_8[AUTO_HEIGHT*AUTO_WIDTH] = 
  {// 
   //AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
   //DFWD,     10,   FULLSPEED,     0,  // Drive Forward (time,speed)
   //AMED,      0,         0,        0,  // Move arm to medium scoring position
   //SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   //DSONIC, 87,	0,	0,	//Drive to predefined distance from rack
   //SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
   //ASONIC, 17,	0,	0,	//Search with arm turret for distance
   //ALETGO,     0,         0,        0,  // Release the tube
   //DELAY,    40,		0,		0,  // Sit still (time)
   //DBCK,     10,   QTRSPEED,     0,  // Drive Backward (time,speed)
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_8[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // 
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_8[AUTO_HEIGHT*AUTO_WIDTH] = 
  {// 
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_9[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Testing
   DSPIN,    10,   FULLSPEED,    CCW,  // Spin (time, speed, CW or CCW) est. 1.5sec=260 deg.,  .6sec = 90 deg.
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_9[AUTO_HEIGHT*AUTO_WIDTH] = 
  {
   DSPIN,    11,   FULLSPEED,    CCW,  // Spin (time, speed, CW or CCW) est. 1.5sec=260 deg.,  .6sec = 90 deg.
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_9[AUTO_HEIGHT*AUTO_WIDTH] = 
  {
   DSPIN,    11,   FULLSPEED,    CCW,  // Spin (time, speed, CW or CCW) est. 1.5sec=260 deg.,  .6sec = 90 deg.
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/

  /******** End autonomous commands ********/
  /*****************************************/
  /*****************************************/

/*******************************************************************************
* TIME is in tenths of seconds
* SPEED is 0-127
*
   ENDCMD,      0,           0,     0,   // ALWAYS the last command in a script
*
* Driving :
*(timed) - 
   DFWD,     TIME,   FULLSPEED,     0,  // Drive Forward (time,speed)
   DSPIN,    TIME,   FULLSPEED,    CW,  // Spin (time, speed, CW or CCW) 1sec=90 deg..
   DBCK,     TIME,   FULLSPEED,     0,  // Drive Backward (time,speed)
   DCURVE, TIME, PERCENT, DIRECTION, // Drive in a curve
   DSONIC, DISTANCE,	0,	0,	//Drive to predefined distance from rack
   DSTOP,    0,          0,         0,  // Unnecessary since all other commands end in a motor stop
*
* Arm:
   AHIGH,     0,         0,        0,  // Move arm to high scoring position
   AMED,      0,         0,        0,  // Move arm to medium scoring position
   ALOW,     0,         0,        0,  // Move arm to low scoring position
   ALETGO,     0,         0,        0,  // Release the tube
   ATURRET,     POSITION,         0,        0,  // Turret position 290-756 (517 is centered)
   ASONIC, DISTANCE,	0,	0,	//Search with Arm until look down distance is found, then drop tube
   AUNFOLD,	0,	0,	0,	// Unfold the arm from the starting stowed position
*
* JOINT:
   DELAY,    TIME,		0,		0,  // Sit still (time)
   SYNC,		0,		0,		0,  // Synchronize Arm and Drive Commands
*
*
* BROKEN COMMANDS:
*
* DIAGNOSTIC COMMANDS:
*
* PARAMETERS:
*  TIME: 1-100 tenths of seconds
*  Distance: inches
*  Direction: CW or CCW
*  Speed: 1-127
*
* NOTES:
* 	 SPIN in '05 2sec=260 deg.,  .8sec = 90 deg. '05 drivetrain=9 fps/ '07 drivetrain=~12fps
*             SPIN should take .75 of '05 robot times, so...
*		1.5sec=260 deg.,  .6sec = 90 deg.
*******************************************************************************/
