/*********************************************************************
* FILE NAME: 	generic_menu.c
* DESCRIPTION:
*********************************************************************/
#include <stdio.h>
#include "ifi_default.h"
#include "ifi_aliases.h"
#include "ifi_utilities.h"
#include "serial_ports.h"
#include "user_routines.h"

#define VARIABLE_DECLARE  /* causes certain global variables to be declared only once */
  #include "generic_menu.h"
#undef VARIABLE_DECLARE

void Menu_Print(void);
void Menu_Start(unsigned char, unsigned char *,  int *);
void Menu_Finish(int, unsigned char *);
void AlphaNumeric_Input(unsigned char, int *, int, unsigned char *);

#define GM_INACTIVE 				0
#define GM_MENU1_PRINT 			1
#define GM_MENU_HANDLER 			2
#define GM_USER_PROMPT 			3
#define GM_GETTING_USER_INPUT 	4
#define GM_USER_INPUT_ERROR 	5
#define GM_PROCESS_USER_INPUT 	6

unsigned char selection;
unsigned char char_buffer_index;
unsigned int counter=0;
unsigned int save_desired_joint1, save_desired_joint2, save_desired_joint3, save_desired_joint4;

#define Myprintf(x)  if(counter%20==0) printf(x)

unsigned int joint1, joint2, joint3, joint4;

/********************************************************************
* FILE NAME: 	Generic_Menu()
* DESCRIPTION:
*	This function manages the tracking menu functionality,
*	which is used to enter tracking parameters using a 
*	terminal attached to the programming port of your robot controller.
* 	Print the menu
*	Wait for input
*	Process input
********************************************************************/
void Generic_Menu(unsigned int *desired_joint1, unsigned int *desired_joint2, unsigned int *desired_joint3, unsigned int *desired_joint4)
{
	static unsigned char menu_state = GM_INACTIVE;
	static int user_number;
	unsigned char terminal_char;
	static char FirstTime=1;
	int default_input_value;

	joint1 = ARM_SHOULDER_POT;
	joint2 = ARM_ELBOW_POT;
	joint3 = ARM_WRIST_POT;
	joint4 = TURRET_POT;

	if (Generic_Menu_Initialize == TRUE)  // Start with the current joint positions
	{
		Generic_Menu_Initialize = FALSE;
		save_desired_joint1 = joint1; save_desired_joint2=joint2; save_desired_joint3=joint3; save_desired_joint4=joint4;
	}

	counter++;
	switch(menu_state)
	{
		// print main menu
		case GM_INACTIVE:
			save_desired_joint1 = joint1; save_desired_joint2=joint2; save_desired_joint3=joint3; save_desired_joint4=joint4;
			if (FirstTime == 1)
			{
				FirstTime = 0;
				printf("\r\nType 'm' for menu\r\n");
			}
			terminal_char = Read_Serial_Port_One();
			// check to see if any "hotkeys" have been pressed
			if(terminal_char == 'm')  // m is for "Menu"
			{
				Menu_Print();
				menu_state = GM_MENU_HANDLER;
			}
			break;

		// handle user input for the main menu -- What to do... what to do...
		case GM_MENU_HANDLER:	// wait for it...wait for it...
			terminal_char = Read_Serial_Port_One();
			Menu_Start(terminal_char, &menu_state, &default_input_value);
			break;

		// prompt user for a new value
		case GM_USER_PROMPT:
			char_buffer_index = 0;	// reset buffer index
			while(Read_Serial_Port_One() != 0);	// flush user input queue
			printf("\r\nEnter new value: ");	// prompt user for input
			menu_state = GM_GETTING_USER_INPUT;	// get and process input
			break;

		// get user input for the new value
		case GM_GETTING_USER_INPUT:
			terminal_char = Read_Serial_Port_One();	// read a byte from the terminal serial port
			AlphaNumeric_Input	(terminal_char, &user_number, default_input_value, &menu_state);
			break;

		// inform user that the value entered is bogus
		case GM_USER_INPUT_ERROR:
			printf("\r\nError: Number out of range.\r\n");	// DOH!
			menu_state = GM_USER_PROMPT;	// ask again for input
			break;

		// get user input for the new value
		case GM_PROCESS_USER_INPUT:
			Menu_Finish(user_number, &menu_state);
			break;
	}
	*desired_joint1 = save_desired_joint1;
	*desired_joint2 = save_desired_joint2;
	*desired_joint3 = save_desired_joint3;
	*desired_joint4 = save_desired_joint4;
}

/*****************************************************************
* FILE NAME: 	Menu_Print()
* DESCRIPTION:
*****************************************************************/
void Menu_Print(void)
{
	printf("\r\n\r\n");
	//printf("[t] Turret = %u\r\n",joint4);
	printf("[s] Shoulder = %u  (+ is up) \r\n",joint1);
	printf("[e] Elbow = %u (+ is in) \r\n",joint2);
	printf("[w] Wrist = %u (+ tucks it in ) \r\n",joint3);
	printf("[z] Show Sonic\r\n");
	printf("[a] Show ARM_HEIGHT\r\n");

	printf("[y] Refresh\r\n");
	printf("[x] Exit\r\n");
	printf("\r\n");
}


/*****************************************************************
* FILE NAME: 	Menu_Start()
* DESCRIPTION:
*****************************************************************/
void Menu_Start(unsigned char terminal_char, unsigned char *menu_state, int *default_input_value)
{
	if(terminal_char == 't')
	{
		*menu_state = GM_USER_PROMPT;	// prompt user for input
		*default_input_value = joint4;
		selection = terminal_char;					// save selection for use in assigning the input
	}
	else if(terminal_char == 's')
	{
		*menu_state = GM_USER_PROMPT;	// prompt user for input
		*default_input_value = joint1;
		selection = terminal_char;					// save selection for use in assigning the input
	}
	else if(terminal_char == 'e')
	{
		*menu_state = GM_USER_PROMPT;	// prompt user for input
		*default_input_value = joint2;
		selection = terminal_char;					// save selection for use in assigning the input
	}
	else if(terminal_char == 'w')
	{
		*menu_state = GM_USER_PROMPT;	// prompt user for input
		*default_input_value = joint3;
		selection = terminal_char;					// save selection for use in assigning the input
	}
	else if(terminal_char == 'z')
	{
		printf("sonic_1=%d\r",SONIC_1);
		//Menu_Print(); // Refresh the menu
		*menu_state = GM_MENU_HANDLER;
	}
	else if(terminal_char == 'a')
	{
		printf("ARM_HEIGHT=%d\r",ARM_HEIGHT);
		*menu_state = GM_MENU_HANDLER;
	}

	else if(terminal_char == 'y')
	{
		printf("\r\r\r\r\r\r\r\r\r\r");
		printf("\r\r\r\r\r\r\r\r\r\r");
		printf("\r\r\r\r\r\r\r\r\r\r");
		printf("\r\r\r\r\r");
		Menu_Print(); // Refresh the menu
		*menu_state = GM_MENU_HANDLER;
	}
	else if(terminal_char == 'x')
	{
		*menu_state = GM_INACTIVE;	// Exit menu system
	}
}

/*****************************************************************
* FILE NAME: 	Menu_Finish()
* DESCRIPTION:
*****************************************************************/
void Menu_Finish(int user_entered_value, unsigned char *menu_state)
{

	// make sure the user entered value is in range for the selected option
	if(selection == 't')
	{
		// This input has a range of 0 to 1023
		if(user_entered_value >= 0 && user_entered_value <= 1023)
		{
			save_desired_joint4 = (unsigned int) user_entered_value;	// save the value
			Menu_Print();
			*menu_state = GM_MENU_HANDLER;
		}
		else
		{
			// bad value entered; ask again
			*menu_state = GM_USER_INPUT_ERROR;
		}
	}
	else if(selection == 's')
	{
		// This input has a range of 0 to 1023
		if(user_entered_value >= 0 && user_entered_value <= 1023)
		{
			save_desired_joint1 = (unsigned int) user_entered_value;	// save the value
			Menu_Print();
			*menu_state = GM_MENU_HANDLER;
		}
		else
		{
			// bad value entered; ask again
			*menu_state = GM_USER_INPUT_ERROR;
		}
	}
	else if(selection == 'e')
	{
		// This input has a range of 0 to 1023
		if(user_entered_value >= 0 && user_entered_value <= 1023)
		{
			save_desired_joint2 = (unsigned int) user_entered_value;	// save the value
			Menu_Print();
			*menu_state = GM_MENU_HANDLER;
		}
		else
		{
			// bad value entered; ask again
			*menu_state = GM_USER_INPUT_ERROR;
		}
	}
	else if(selection == 'w')
	{
		// This input has a range of 0 to 1023
		if(user_entered_value >= 0 && user_entered_value <= 1023)
		{
			save_desired_joint3 = (unsigned int) user_entered_value;	// save the value
			Menu_Print();
			*menu_state = GM_MENU_HANDLER;
		}
		else
		{
			// bad value entered; ask again
			*menu_state = GM_USER_INPUT_ERROR;
		}
	}
	else
	{
		*menu_state = GM_MENU_HANDLER;
	}
}


/******************************************************************
* FILE NAME: 	AlphaNumeric_Input()
* DESCRIPTION:
*	Grab all user input 
******************************************************************/
void AlphaNumeric_Input(unsigned char terminal_char, int *user_number, int default_number, unsigned char *menu_state)
{
	static unsigned char char_buffer[6];
	int i, sign;


	if(((terminal_char >= '0' && terminal_char <= '9') || 
			terminal_char == '+' || terminal_char == '-') && 
			char_buffer_index < sizeof(char_buffer))
	{	// make sure it's a decimal number or +/- sign and we don't overflow the buffer	
		Write_Serial_Port_One(terminal_char);	// echo the character back to the terminal
		char_buffer[char_buffer_index] = terminal_char;	// add the new character to the buffer
		char_buffer_index++;	// increment buffer index			
	}
	else if(terminal_char == '\r')	// When the user hits the return key add it all up
	{
		*menu_state = GM_PROCESS_USER_INPUT;
		if(char_buffer[0] == '-')	// did the user enter a negative number?
		{
			sign = -1;	// remember the sign and convert to a positive number
			char_buffer_index--;
			for(i=0; i<sizeof(char_buffer); i++)	//left shift our number
			{
				char_buffer[i] = char_buffer[i+1];
			}
		}
		else if(char_buffer[0] == '+')
		{
			sign = 1;	// number is already positive
			char_buffer_index--;
			for(i=0; i<sizeof(char_buffer); i++)	//left shift our number
			{
				char_buffer[i] = char_buffer[i+1];
			}
		}
		else
		{
			sign = 1;	// if there's no sign, we'll assume it's a positive number
		}
				
		// consider checking to make sure user didn't enter a +/- sign elsewhere

		if(char_buffer_index > 4) // too many digits entered?
		{
			*user_number = 1023; // make sure valid number logic (below) handles the situation
		}					
		else if(char_buffer_index == 4) // four decimal digits entered?
		{
			*user_number = 1000*(unsigned int)(char_buffer[0]-'0');
			*user_number += 100*(unsigned int)(char_buffer[1]-'0');
			*user_number += 10*(unsigned int)(char_buffer[2]-'0'); 
			*user_number += (unsigned int)(char_buffer[3]-'0');
			*user_number *= sign;
		}
		else if(char_buffer_index == 3) // three decimal digits entered?
		{
			*user_number = 100*(unsigned int)(char_buffer[0]-'0');
			*user_number += 10*(unsigned int)(char_buffer[1]-'0'); 
			*user_number += (unsigned int)(char_buffer[2]-'0');
			*user_number *= sign;
		}
		else if(char_buffer_index == 2) // two decimal digits entered?
		{
			*user_number = 10*(char_buffer[0]-'0'); 
			*user_number += (char_buffer[1]-'0');
			*user_number *= sign;
		}
		else if(char_buffer_index == 1) // one decimal digit entered?
		{
			*user_number = char_buffer[0] - '0';
			*user_number *= sign;
		}
		else if(char_buffer_index == 0) // no decimal digits entered (i.e., user just entered <return> or '-')?
		{
			*user_number = default_number;	// use the default value if no other is entered
		}
	}
}

