 /*******************************************************************************
* FILE NAME: main.c <FRC VERSION>
*
* DESCRIPTION:
*  This file contains the main program loop.
*
* USAGE:
*  You should not need to modify this file.
*  Note the different loop speed for the two routines:
*     Process_Data_From_Master_uP
*     Process_Data_From_Local_IO
*******************************************************************************/

#include "ifi_aliases.h"
#include "ifi_default.h"
#include "ifi_utilities.h"
#include "user_routines.h"

tx_data_record txdata;          /* DO NOT CHANGE! */
rx_data_record rxdata;          /* DO NOT CHANGE! */
packed_struct statusflag;       /* DO NOT CHANGE! */

char AutoFirstTime=TRUE;  // Identifies when Autonomous mode first starts
char OprFirstTime=TRUE;  // Identifies when Autonomous mode first starts

/*******************************************************************************
* FUNCTION NAME: main
* PURPOSE:       Main program function.
* CALLED FROM:   ifi_startup.c
* ARGUMENTS:     none
* RETURNS:       void
* DO NOT DELETE THIS FUNCTION 
*******************************************************************************/
#define STARTDELAY 38    // ~ One second at 26.2ms/loop or use the system clock
void main (void)
{
  /* Give the RC & OI systems time to yawn, stretch, have a little coffee - generally wake-up */
  /* Note sensors powered directly from 12v supply (eg Banners) may not initialize at the same time */
	static char warmUp= STARTDELAY;  // ~ One half second at 26.2ms/loop

#ifdef UNCHANGEABLE_DEFINITION_AREA
	IFI_Initialization ();        /* DO NOT CHANGE! */
#endif

	User_Initialization();
	AutoFirstTime=TRUE;   // Reinitialize Autonomous mode whenever it's entered for the first time
	OprFirstTime=TRUE;    // Reinitialize Operator mode whenever it's entered for the first time
	// Set proper initial starting conditions - 
	UNLOCK_WHEELS;
	PUSH_UP;
	SHIFT_HIGH;
	TUBE_GRAB;

	statusflag.NEW_SPI_DATA = 0;  /* DO NOT CHANGE! */ 

	while (1)   /* This loop will repeat indefinitely. */
	{
#ifdef _SIMULATOR
		statusflag.NEW_SPI_DATA = 1;
#endif

		if (statusflag.NEW_SPI_DATA)     // 26.2ms loop area
		{ // I'm slow!  I only execute every 26.2ms because that's how fast the Master uP gives me data.
			Getdata(&rxdata);   // Get fresh data from the master microprocessor.
			if (warmUp > 0) // digital & OI inputs are suspect @ startup. Give them time to warm up
			{
				warmUp--;
			}
			else
			{
				Process_Data_From_Master_uP();

				if (disabled_mode)  // Robot is disabled
				{
					AutoFirstTime=TRUE; // Reset autonomous whenever the robot is disabled
					OprFirstTime=TRUE; // Reset autonomous whenever the robot is disabled
				}
				else if (autonomous_mode)  // Robot is in autonomous
				{
					User_Autonomous_Code();
					OprFirstTime=TRUE; // Reset autonomous whenever the robot is disabled
				}
				else  // Robot is in normal human driver mode
				{
					Driver_Routine();
					AutoFirstTime=TRUE; // Reset autonomous whenever the driver takes over
				}
			}
			Putdata(&txdata);
		}

		if (warmUp == 0) // digital & OI inputs are suspect @ startup. Give them time to warm up
			Process_Data_From_Local_IO();  // I'm fast!  I execute during every chance I get.

	} /* while (1) */
}  /* END of Main */


/******************************************************************************/
/******************************************************************************/
/******************************************************************************/
