/*******************************************************************************
*
*	TITLE:		user_menu.c
*
*******************************************************************************/
#include <stdio.h>
#include "ifi_default.h"
#include "ifi_aliases.h"
#include "serial_ports.h"
#include "tracking_menu.h"

unsigned int turretjoint4, shoulderjoint1, elbowjoint2, wristjoint3;
unsigned int kp1, kp2, kp3, kp4;

/*******************************************************************************
*
*	FUNCTION:		User_Menu()
*
*******************************************************************************/
unsigned char User_Menu(void)
{	
	static unsigned char user_menu_active = 0;  // User menu is active
	static unsigned char menu_state = UM_INITIALIZE;
	static unsigned char char_buffer[6];
	static unsigned char char_buffer_index;
	static unsigned char offset;
	static unsigned char selection;
	static unsigned char current_value;
	unsigned char terminal_char;
	unsigned char byte;
	static unsigned char i;
	int user_entered_value;
	int sign;

	unsigned int current_value;
	char field_flag;

	// Get current joint positions
	turretjoint4 = TURRET_POT;
	shoulderjoint1 = SHOULDER_POT;
	elbowjoint2 = ELBOW_POT;
	wristjoint3 = WRIST_POT;


	switch(menu_state)
	{
		//
		// initialize the user menu state machine
		//
		case UM_INITIALIZE:
			Get_Coefficients(&kp1, &kp2, &kp3, &kp4);  // Get starting coefficients
			user_menu_active = 1;
			menu_state = UM_MENU_PRINT;
			break;

		//
		// print main menu
		//
		case UM_MENU_PRINT:
			User_Menu_Print();
			menu_state = UM_MENU_HANDLER;
			break;

		//
		// handle user input for the main menu
		//
		case UM_MENU_HANDLER:
			terminal_char = Read_Terminal_Serial_Port();
			if(terminal_char >= 'a' && terminal_char <= 'r')
			{
				menu_state = UM_USER_PROMPT;  // prompt user for input
				selection = terminal_char;  // save selection for use in error checking
				
				//offset = terminal_char - 'a' + 2;  // calculate offset into the configuration structure to change
				if(terminal_char == 'a')
				{
					field_flag = 4;
					current_value = turretjoint4;
				}
				else if(terminal_char == 'b')
				{
					field_flag = 1;
					current_value = shoulderjoint1;
				}
				else if(terminal_char == 'c')
				{
					field_flag = 2;
					current_value = elbowjoint2;
				}
				else if(terminal_char == 'd')
				{
					field_flag = 3;
					current_value = wristjoint3;
				}
				else if(terminal_char == 'i')
				{
					field_flag = 5;
					current_value = kp1;
				}
				else if(terminal_char == 'j')
				{
					field_flag = 6;
					current_value = kp2;
				}
				else if(terminal_char == 'k')
				{
					field_flag = 7;
					current_value = kp3;
				}
				else if(terminal_char == 'l')
				{
					field_flag = 8;
					current_value = kp4;
				}
			}
			else if(terminal_char == 'u')
			{
				Sub_Menu_Print();  // display Sub-menu
				menu_state = UM_SUB_MENU_HANDLER;  // goto Sub-menu
			}
			else if(terminal_char == 'x')
			{
				// reinitialize when/if User_Menu() is called again
				menu_state = UM_INITIALIZE;
				user_menu_active = 0;
			}
			break;

		//
		// prompt user for a new value
		//
		case UM_USER_PROMPT:
			char_buffer_index = 0;  // reset buffer index
			while(Read_Terminal_Serial_Port() != 0);  // flush user input queue
			printf("\r\nEnter new value: ");  // prompt user for input
			menu_state = UM_GETTING_USER_INPUT;  // get and process input
			break;

		//
		// get user input for the new value
		//
		case UM_GETTING_USER_INPUT:
			terminal_char = Read_Terminal_Serial_Port(); // read a byte from the terminal serial port
			// make sure it's a decimal number or +/- sign and we don't overflow the buffer
			if(((terminal_char >= '0' && terminal_char <= '9') || 
				terminal_char == '+' || terminal_char == '-') && 
				char_buffer_index < sizeof(char_buffer))
			{
				// echo the character back to the terminal
				Write_Terminal_Serial_Port(terminal_char);
				// add the new character to the buffer
				char_buffer[char_buffer_index] = terminal_char;
				// increment buffer index
				char_buffer_index++;			
			}
			// did the user hit the return key?
			else if(terminal_char == '\r')
			{
				// did the user enter a negative number?
				if(char_buffer[0] == '-')
				{
					// remember the sign and convert to a positive number
					sign = -1;
					char_buffer_index--;
					//left shift our number
					for(i=0; i<sizeof(char_buffer); i++)
					{
						char_buffer[i] = char_buffer[i+1];
					}
				}
				else if(char_buffer[0] == '+')
				{
					// number is already positive
					sign = 1;
					char_buffer_index--;
					//left shift our number
					for(i=0; i<sizeof(char_buffer); i++)
					{
						char_buffer[i] = char_buffer[i+1];
					}
				}

				else
				{
					// if there's no sign, we'll assume it's a positive number
					sign = 1;
				}
				
				// consider checking to make sure user didn't enter a +/- sign elsewhere

				if(char_buffer_index > 4) // too many digits entered?
				{
					user_entered_value = 1023; // make sure valid number logic (below) handles the situation
				}					
				else if(char_buffer_index == 4) // Four decimal digits entered?
				{
					user_entered_value = 1000*(unsigned int)(char_buffer[0]-'0');
					user_entered_value += 100*(unsigned int)(char_buffer[1]-'0');
					user_entered_value += 10*(unsigned int)(char_buffer[2]-'0'); 
					user_entered_value += (unsigned int)(char_buffer[3]-'0');
					user_entered_value *= sign;
				}
				else if(char_buffer_index == 3) // three decimal digits entered?
				{
					user_entered_value = 100*(unsigned int)(char_buffer[0]-'0');
					user_entered_value += 10*(unsigned int)(char_buffer[1]-'0'); 
					user_entered_value += (unsigned int)(char_buffer[2]-'0');
					user_entered_value *= sign;
				}
				else if(char_buffer_index == 2) // two decimal digits entered?
				{
					user_entered_value = 10*(char_buffer[0]-'0'); 
					user_entered_value += (char_buffer[1]-'0');
					user_entered_value *= sign;
				}
				else if(char_buffer_index == 1) // one decimal digit entered?
				{
					user_entered_value = char_buffer[0] - '0';
					user_entered_value *= sign;
				}
				else if(char_buffer_index == 0) // no decimal digits entered (i.e., user just entered <return> or '-')?
				{
					// use the current value
					user_entered_value = current_value;
				}

				// make sure the user entered value is in range for the selected option
		
				// everything here has a range of 0 to 1023
				if(user_entered_value >= 0 && user_entered_value <= 1023)
				{
					// Save the new value
					if (field_flag == 1)
						shoulderjoint1 = user_entered_value;
					else if (field_flag == 2)
						elbowjoint1 = user_entered_value;
					else if (field_flag == 3)
						wristjoint1 = user_entered_value;
					else if (field_flag == 4)
						turretjoint1 = user_entered_value;
					else if (field_flag == 5)
						kp1 = user_entered_value;
					else if (field_flag == 6)
						kp2 = user_entered_value;
					else if (field_flag == 7)
						kp3 = user_entered_value;
					else if (field_flag == 8)
						kp4 = user_entered_value;
					// back to the main menu
					menu_state = UM_MENU_PRINT;
				}
				else
				{
					// bad value entered; ask again
					menu_state = UM_USER_INPUT_ERROR;
				}
				
			}
			break;

		//
		// inform user that the value entered is bogus
		//
		case TM_USER_INPUT_ERROR:
			printf("\r\nError: Number out of range.\r\n");  // DOH!
			menu_state = UM_USER_PROMPT;  // ask again for input
			break;
	}
	return(user_menu_active);
}



/*******************************************************************************
*
*	FUNCTION:		User_Menu_Print()
*
*******************************************************************************/
void User_Menu_Print(void)
{
	printf("\r\n");
	printf("\r\n");
	printf("[a] Change Turret   position = %u\r\n",(unsigned int)turretjoint4);
	printf("[b] Change Shoulder position = %u\r\n",(unsigned int)shoulderjoint1);
	printf("[c] Change Elbow    position = %u\r\n",(unsigned int)elbowjoint2);
	printf("[d] Change Wrist    position = %u\r\n",(unsigned int)wristjoint3);
	printf("\r\n");
	printf("[i] Change Turret   Kp4 = %u\r\n",(unsigned int)kp4);
	printf("[j] Change Shoulder Kp1 = %u\r\n",(unsigned int)kp1);
	printf("[k] Change Elbow    kp2 = %u\r\n",(unsigned int)kp2);
	printf("[l] Change Wrist    kp3 = %u\r\n",(unsigned int)kp3);
	printf("\r\n");
	printf("[x] Exit\r\n");
	printf("\r\n");
}


