/*******************************************************************************
* FILE NAME: user_routines.c <FRC VERSION>
*
* DESCRIPTION:
*  This file contains the default mappings of inputs  
*  (like switches, joysticks, and buttons) to outputs on the RC.  
*
*******************************************************************************/

#include <stdio.h>

#include "ifi_aliases.h"
#include "ifi_default.h"
#include "ifi_utilities.h"
#include "user_routines.h"
#include "serial_ports.h"
//#include "pwm.h"
#include "camera.h"
#include "tracking.h"
#include "terminal.h"
#include "arm_control.h"
#include "generic_menu.h"
#include "clock_routines.h"
#include "arm_control.h"


/*******************************************************************************
* FUNCTION NAME: Limit_Mix
* PURPOSE:       Limits the mixed value for one joystick drive.
*******************************************************************************/
unsigned char Limit_Mix (int intermediate_value)
{
  static int limited_value;
  
  if (intermediate_value < 2000)
  {
    limited_value = 2000;
  }
  else if (intermediate_value > 2254)
  {
    limited_value = 2254;
  }
  else
  {
    limited_value = intermediate_value;
  }
  return (unsigned char) (limited_value - 2000);
}


/*******************************************************************************
* FUNCTION NAME: User_Initialization
* PURPOSE:       This routine is called first (and only once) in the Main function.  
*                You may modify and add to this function.
* CALLED FROM:   main.c
* ARGUMENTS:     none
* RETURNS:       void
*******************************************************************************/
void User_Initialization (void)
{
  Set_Number_of_Analog_Channels(SIXTEEN_ANALOG);    /* DO NOT CHANGE! */

/* FIRST: Set up the I/O pins you want to use as digital INPUTS. */
  digital_io_01 = digital_io_02 = digital_io_03 = digital_io_04 = INPUT;
  digital_io_05 = digital_io_06 = digital_io_07 = digital_io_08 = INPUT;
  digital_io_09 = digital_io_10 = digital_io_11 = digital_io_12 = INPUT;
  digital_io_13 = digital_io_14 = digital_io_15 = digital_io_16 = INPUT;
  digital_io_18 = INPUT;  /* Used for pneumatic pressure switch. */
  digital_io_17 = INPUT;  

/* SECOND: Set up the I/O pins you want to use as digital OUTPUTS. */
//  digital_io_17 = OUTPUT;    /* Example - Not used in Default Code. */

/* THIRD: Initialize the values on the digital outputs. */
//  rc_dig_out17 = 0;

/* FOURTH: Set your initial PWM values.  Neutral is 127. */
  pwm01 = pwm02 = pwm03 = pwm04 = pwm05 = pwm06 = pwm07 = pwm08 = 127;
  pwm09 = pwm10 = pwm11 = pwm12 = pwm13 = pwm14 = pwm15 = pwm16 = 127;

/* FIFTH: Set your PWM output types for PWM OUTPUTS 13-16.
  /*   Choose from these parameters for PWM 13-16 respectively:               */
  /*     IFI_PWM  - Standard IFI PWM output generated with Generate_Pwms(...) */
  /*     USER_CCP - User can use PWM pin as digital I/O or CCP pin.           */
//  Setup_PWM_Output_Type(IFI_PWM,IFI_PWM,IFI_PWM,IFI_PWM);

  // changed so PWM() can control PWM outputs 13 through 16
  Setup_PWM_Output_Type(USER_CCP,USER_CCP,USER_CCP,USER_CCP);

  /* Add any other initialization code here. */

  // initialize the serial ports
  Init_Serial_Port_One();
  Init_Serial_Port_Two();

#ifdef TERMINAL_SERIAL_PORT_1    
  stdout_serial_port = SERIAL_PORT_ONE;
#endif

#ifdef TERMINAL_SERIAL_PORT_2    
  stdout_serial_port = SERIAL_PORT_TWO;
#endif

	Initialize_Clock();

  Putdata(&txdata);            /* DO NOT CHANGE! */

  User_Proc_Is_Ready();         /* DO NOT CHANGE! - last line of User_Initialization */
}

/*******************************************************************************
* FUNCTION NAME: Process_Data_From_Master_uP
* PURPOSE:       Executes every 26.2ms when it gets new data from the master microprocessor.
*******************************************************************************/
void Process_Data_From_Master_uP(void)
{
	//Getdata(&rxdata);

	//PacketNum_Check(); // Print a Warning if we're dropping radio packets
	COMPRESSOR = PRESSURE;  /* Power pump if pressure switch is off. */    
	Update_Clock();
	OI_Display();  // Update the OI LEDs and dashboard display

//	Tracking_Info_Terminal();	// send diagnostic information to the terminal
//	Camera_Handler();
//	Servo_Track();

	//Putdata(&txdata);
}

/*******************************************************************************
* FUNCTION NAME: Driver_Routine
* PURPOSE:       Performs the default mappings of inputs to outputs for the Robot Controller.
*******************************************************************************/
void Driver_Routine(void)
{
  static char grabber_toggle=1;

  if (OprFirstTime)
  { /* Initialize the first time Operator mode starts */
    OprFirstTime = FALSE;
    EndOfOpr=FALSE; // One second Flag warning of the pending end of Operator mode
    LastSecOfOpr = Clocksec + ENDOFOPR - 3;  // 1 wasn't long enough
    Switch2_LED = 0;
  }

// *********** Base driver ***********
// Deadband
  if (LEFT_DRIVE > (127-10) && LEFT_DRIVE < (127+10))
  {
	LEFT_DRIVE = 127;
  }
  if (RIGHT_DRIVE > (127-10) && RIGHT_DRIVE < (127+10))
  {
	RIGHT_DRIVE = 127;
  }
  LEFT_MOTOR_1 =  LEFT_MOTOR_2 = LEFT_DRIVE;	// Left side  
  RIGHT_MOTOR_1 =  RIGHT_MOTOR_2 = 254 - RIGHT_DRIVE;	// Right side
  

// ---------- 1 Joystick Drive (unused) ----------------------------------------

  pwm13 = pwm14 = 255 - Limit_Mix(2000 + p1_y + p1_x - 127);
  pwm15 = pwm16 = Limit_Mix(2000 + p1_y - p1_x + 127);

// Wheel locks
  if (LEFT_MOTOR_1 == 127 && RIGHT_MOTOR_1 == 127)
  {
	if (WHEEL_LOCKS)
	{
		// Allow wheels to be locked
		LOCK_WHEELS;
//  		relay4_fwd = 1;
//  		relay4_rev  = 0; 
	}
  }
  else
  { // Insure wheels are NOT locked while driving
	UNLOCK_WHEELS;
//  	relay4_fwd = 0;
//  	relay4_rev = 0;
  }

// Push-down pads
  if(PUSH_DOWN1 || PUSH_DOWN2)
  {
	PUSH_DOWN;
//    relay5_fwd = 1 ;
//    relay5_rev = 0;
  }
  else
  {
	PUSH_UP;
//    relay5_fwd = 0 ;
//    relay5_rev = 0;
  }

// Gear shift
  if (GEAR_SHIFT_LOW)
  {
	SHIFT_LOW;
// 	relay6_fwd = 1;
//  	relay6_rev  = 0;
  }
  if (GEAR_SHIFT_HIGH)
  {
	SHIFT_HIGH;
// 	relay6_fwd = 0;
//  	relay6_rev  = 0;
  }

// *********** Arm Operator ***********
// Turret & Arm extension
  Arm_Control();

// Grabber
  if(GRABBER && grabber_toggle)
  {
	grabber_toggle = 0;
	TUBE_TOGGLE;
//  	relay7_fwd = !relay7_fwd; 
//  	relay7_rev = 0;
  }
  if(!GRABBER)
  {
	grabber_toggle = 1;
  }
//if (Clockds % 10) printf("grabber=%d grabber_toggle=%d\r", GRABBER, grabber_toggle);  // DEBUG

  if ((AUTOMATIC_TUBE_DROP==1) && (Spider_Sonic_Check() == TRUE))	// Recognize if the spider is within hearing
  {
	//TUBE_DROP;
  }


// Compressor
  //relay8_fwd = !rc_dig_in14;  /* Power pump only if pressure switch is off. */
  //relay8_rev = 0;

  if(EndOfOpr)
  { // Last second to act before being disabled
	Switch2_LED = 1;
	//TUBE_DROP;
	//LOCK_WHEELS;
  }

} /* END Default_Routine(); */

/******************************************************************************/
/******************************************************************************/
/******************************************************************************/


/*******************************************************************************
* FUNCTION NAME: Spider_Sonic_Check
* PURPOSE:       Does the down looking sensor see a spider?
* NOTES:
*	The sensor is wired to free run and new data samples come at 20Hz, or about half the rate we check it within 
*	our low loop.
* Looking down at spider:	spider	Floor	Pipe	top of spider
*	(approx)				Low	76		38		17
*							High					184
* 							Med					141
*							Low					25
*******************************************************************************/
#define SPIDER_DEADBAND	10
#define SPIDER_RANGE	17
#define SPIDER_RANGE_LOW		25
#define SPIDER_RANGE_MED		25
#define SPIDER_RANGE_HIGH		25
#define PIPE_RANGE		38 //old

char Spider_Sonic_Check()
{
	char success=FALSE;
	unsigned char spider;
	unsigned int range;

	switch(arm_position)
	{
		case HIGH:
			spider = SPIDER_RANGE_HIGH;
			break;
		case MEDIUM:
			spider = SPIDER_RANGE_MED;
			break;
		case LOW:
			spider = SPIDER_RANGE_LOW;
			break;
		default:
			spider = SPIDER_RANGE_LOW;
			break;
	}

	range = SONIC_1;
	//if(Clockds%20 == 0) printf("SONIC_1=%u\r", SONIC_1);
	if (range < (spider+SPIDER_DEADBAND) )
	{  
		success = TRUE;
	}
	else
	{
		success = FALSE;
	}
	return(success);
}
