/*******************************************************************************
* FILE NAME: user_routines.h
*
* DESCRIPTION: 
*  This is the include file which corresponds to user_routines.c and
*  user_routines_fast.c
*  It contains some aliases and function prototypes used in those files.
*
* USAGE:
*  If you add your own routines to those files, this is a good place to add
*  your custom macros (aliases), type definitions, and function prototypes.
*******************************************************************************/

#ifndef __user_program_h_
#define __user_program_h_


/*******************************************************************************
                            MACRO DECLARATIONS
*******************************************************************************/

/* Used in limit switch routines in user_routines.c */
#define OPEN        1     /* Limit switch is open (input is floating high). */
#define CLOSED      0     /* Limit switch is closed (input connected to ground). */

/*******************************************************************************
                            IO DECLARATIONS
*******************************************************************************/
  extern char AutoFirstTime, OprFirstTime;

// Robot Controller
#define COMPRESSOR relay8_fwd
#define PRESSURE		!rc_dig_in14
#define AUTOMODE ~PORTJ>>4
#define FIELD_LEFT   rc_dig_in11
#define FIELD_CENTER rc_dig_in12
#define FIELD_RIGHT  rc_dig_in13

#define TUBE_GRAB 	relay7_fwd=0; relay7_rev=0;
#define TUBE_DROP 	relay7_fwd=1; relay7_rev=0;
#define TUBE_TOGGLE   	relay7_fwd = !relay7_fwd; relay7_rev = 0;
#define SHIFT_LOW	relay6_fwd = 1; relay6_rev  = 0;; // Shift into LOW gear
#define SHIFT_HIGH	relay6_fwd = 0; relay6_rev  = 0;  // Shift into HIGH gear
#define PUSH_DOWN	relay5_fwd = 1; relay5_rev = 0;   // Extend push-down pads
#define PUSH_UP		relay5_fwd = 0; relay5_rev = 0;   // Retract push-down pads
//#define LOCK_WHEELS	relay4_fwd = 1;relay4_rev  = 0; 
//#define UNLOCK_WHEELS	relay4_fwd = 0;relay4_rev  = 0; 
#define LOCK_WHEELS	relay4_fwd = 1;relay4_rev  = 0; 
#define UNLOCK_WHEELS	relay4_fwd = 0;relay4_rev  = 1; 


#define TURRET_POT 				Get_Analog_Value(rc_ana_in01)
#define ARM_SHOULDER_POT 	Get_Analog_Value(rc_ana_in02)
#define ARM_ELBOW_POT 		Get_Analog_Value(rc_ana_in03)
#define ARM_WRIST_POT 		Get_Analog_Value(rc_ana_in04)
#define SONIC_1 					Get_Analog_Value(rc_ana_in05)  // look down
#define SONIC_2 					Get_Analog_Value(rc_ana_in06)	// look straight out

#define LEFT_MOTOR_1 			pwm01
#define LEFT_MOTOR_2 			pwm02
#define RIGHT_MOTOR_1 			pwm03
#define RIGHT_MOTOR_2 			pwm04
#define TURRET_MOTOR 			pwm05
#define SHOULDER_MOTOR_1 	pwm06
#define SHOULDER_MOTOR_2 	pwm07
#define ELBOW_MOTOR 			pwm08
#define WRIST_MOTOR 			pwm09
#define PAN_SERVO 				pwm10
#define TILT_SERVO 				pwm11


// Operator Interface
// Base Driver
#define GEAR_SHIFT_LOW	p1_sw_top
#define GEAR_SHIFT_HIGH	p4_sw_top
//#define GEAR_SHIFT_HIGH	p2_sw_top
#define PUSH_DOWN1			p1_sw_trig
#define PUSH_DOWN2			p1_sw_trig
#define LEFT_DRIVE			p4_y
//#define LEFT_DRIVE			p2_y
#define WHEEL_LOCKS		p4_sw_trig
//#define WHEEL_LOCKS		p2_sw_trig
#define RIGHT_DRIVE			p1_y

//Arm Operator
#define TURRET_DRIVE		127
//#define TURRET_DRIVE		p3_x
#define ARM_EXTENSION		p3_y
#define GRABBER				p3_sw_trig
//#define STOW_ARM			p4_sw_top
#define STOW_ARM			p2_sw_top
//#define ARM_MODE			p4_aux 		// Analog used as a digital switch
#define ARM_MODE			p2_aux 		// Analog used as a digital switch
//#define ARM_HEIGHT			p4_wheel	// Analog used as a digital switch
//#define ARM_HEIGHT			p4_x	// Analog used as a digital switch
#define ARM_HEIGHT			p2_x	// Analog used as a digital switch
#define AUTOMATIC_TUBE_DROP	p3_sw_top
#define ARM_DUNK	p3_sw_top

/*******************************************************************************
                           FUNCTION PROTOTYPES
*******************************************************************************/

/* These routines reside in user_routines.c */
void User_Initialization(void);
void Process_Data_From_Master_uP(void);
void Driver_Routine(void);

/* These routines reside in user_routines_fast.c */
void InterruptHandlerLow (void);  /* DO NOT CHANGE! */
void User_Autonomous_Code(void);  /* Only in full-size FRC system. */
void Process_Data_From_Local_IO(void);

void OI_Display(void);
char Spider_Sonic_Check(void);

#endif
/******************************************************************************/
/******************************************************************************/
/******************************************************************************/
