/*******************************************************************************
* FILE NAME: user_routines_fast.c <FRC VERSION>
*
* DESCRIPTION:
*  This file is where the user can add their custom code within the framework
*  of the routines below. 
*
* USAGE:
*  You can either modify this file to fit your needs, or remove it from your 
*  project and replace it with a modified copy. 
*
* OPTIONS:  Interrupts are disabled and not used by default.
*
*******************************************************************************/

#include <stdio.h>
#include "ifi_aliases.h"
#include "ifi_default.h"
#include "ifi_utilities.h"
#include "user_routines.h"
#include "serial_ports.h"
//#include "camera.h"
//#include "tracking.h"
//#include "terminal.h"
//#include "pwm.h"
#include "clock_routines.h"


/*******************************************************************************
* FUNCTION NAME: InterruptVectorLow
* PURPOSE:       Low priority interrupt vector
* DO NOT MODIFY OR DELETE THIS FUNCTION 
*******************************************************************************/
#pragma code InterruptVectorLow = LOW_INT_VECTOR
void InterruptVectorLow (void)
{
  _asm
    goto InterruptHandlerLow  /*jump to interrupt routine*/
  _endasm
}


/*******************************************************************************
* FUNCTION NAME: InterruptHandlerLow
* PURPOSE:       Low priority interrupt handler
* If you want to use these external low priority interrupts or any of the
* peripheral interrupts then you must enable them in your initialization
* routine.  Innovation First, Inc. will not provide support for using these
* interrupts, so be careful.  There is great potential for glitchy code if good
* interrupt programming practices are not followed.  Especially read p. 28 of
* the "MPLAB(R) C18 C Compiler User's Guide" for information on context saving.
* CALLED FROM:   this file, InterruptVectorLow routine
*******************************************************************************/
#pragma code
#pragma interruptlow InterruptHandlerLow save=PROD,section("MATH_DATA"),section(".tmpdata")

void InterruptHandlerLow ()     
{
//  unsigned char Port_B;
//  unsigned char Port_B_Delta;       
//  static unsigned char Old_Port_B = 0xFF; // state of port b the last time this function was called

	if (PIR1bits.RC1IF && PIE1bits.RC1IE) // rx1 interrupt?
	{
		#ifdef ENABLE_SERIAL_PORT_ONE_RX
		Rx_1_Int_Handler(); // call the rx1 interrupt handler (in serial_ports.c)
		#endif
	}                              
	else if (PIR3bits.RC2IF && PIE3bits.RC2IE) // rx2 interrupt?
	{
		#ifdef ENABLE_SERIAL_PORT_TWO_RX
		Rx_2_Int_Handler(); // call the rx2 interrupt handler (in serial_ports.c)
		#endif
	} 
	else if (PIR1bits.TX1IF && PIE1bits.TX1IE) // tx1 interrupt?
	{
		#ifdef ENABLE_SERIAL_PORT_ONE_TX
		Tx_1_Int_Handler(); // call the tx1 interrupt handler (in serial_ports.c)
		#endif
	}                              
	else if (PIR3bits.TX2IF && PIE3bits.TX2IE) // tx2 interrupt?
	{
		#ifdef ENABLE_SERIAL_PORT_TWO_TX
		Tx_2_Int_Handler(); // call the tx2 interrupt handler (in serial_ports.c)
		#endif
	}

  if (PIR2bits.TMR3IF)	/* TIMER 3 INTERRUPT */
  {
    /** This provides us with a clock for timing events **/

    PIR2bits.TMR3IF = 0;	/* Clear Timer interrupt flag */
    WriteTimer3(CLOCKOFFSET);  /* Reset Timer to overflow in 4ms */
    MasterClockms += 4; /* milliseconds */
//printf("M");
  }

#ifdef MLM
if (INTCONbits.RBIF) // external interrupts 3 through 6
  {
	Port_B = PORTB; // remove the "mismatch condition" by reading port b            
	INTCONbits.RBIF = 0; // clear the interrupt flag
	Port_B_Delta = Port_B ^ Old_Port_B; // determine which bits have changed
	Old_Port_B = Port_B; // save a copy of port b for next time around
	 
	if(Port_B_Delta & 0x10) // Check interrupt 3
	{
	}
	if(Port_B_Delta & 0x20) // Check interrupt 4
	{
	}
	if(Port_B_Delta & 0x40) // Check interrupt 5
	{
	}
	if(Port_B_Delta & 0x80) // Check interrupt 6
	{
	}
  }
#endif //MLM
}



/*******************************************************************************
* FUNCTION NAME: Process_Data_From_Local_IO
* PURPOSE:       Execute user's realtime code.
* You should modify this routine by adding code which you wish to run fast.
* It will be executed every program loop, and not wait for fresh data 
* from the Operator Interface.
*******************************************************************************/
void Process_Data_From_Local_IO(void)
{
  /* Add code here that you want to be executed every program loop. */
}


/******************************************************************************/
/******************************************************************************/
/******************************************************************************/
